@@ -58,11 +58,9 @@ pub fn assert_booted() {
 #[macro_export]
 macro_rules! call_on_boot {
   ($boot_fn:block) => {
-    use $crate::{atomic_take::AtomicTake, inventory, BootBox};
-
-    inventory::submit! {
-      BootBox {
-        boot_fn: AtomicTake::new(Box::new(|| $boot_fn))
+    $crate::inventory::submit! {
+      $crate::BootBox {
+        boot_fn: $crate::atomic_take::AtomicTake::new(Box::new(|| $boot_fn))
       }
     }
   };
